from ngsolve import *
import netgen.geom2d as geo2d
import ngsolve.comp
from ngsolve.comp import ConvertOperator

mesh = Mesh(geo2d.unit_square.GenerateMesh(maxh=0.4))

V = VectorH1(mesh, order=1)
Q = H1(mesh, order=1)

u_0 = GridFunction(V)
u_0.Set( CoefficientFunction( (1, 0) ) )

u, v = V.TnT()
p, q = Q.TnT()

# The operator u \in V -> I_h(u\cdot u_0) \in Q
Ih = ConvertOperator(spacea=V, spaceb=Q, trial_cf=InnerProduct(u, u_0))

print(Ih)

# Bilinearform p*q
a = BilinearForm(Q)
a += p * q * dx
a.Assemble()

# The matrix for q * I_h(u\cdot u_0)
blf_mat = a.mat @ Ih

print(blf_mat)
